from contextlib import contextmanager
from sqlalchemy import create_engine, Engine
from sqlalchemy.orm import sessionmaker


def create_session_class(engine: Engine):
    return sessionmaker(bind=engine)


@contextmanager
def session_scope(database_url: str):
    Session = create_session_class(create_engine(database_url))
    session = Session()
    try:
        yield session
        session.commit()
    except Exception:
        session.rollback()
        raise
    finally:
        session.close()
